%function [inputStruct] = initTDQCparams(dataInputStr,preprocessing,sigma)
%   Input
%   dataInputStr - the input dataset (the string representing the variable)
%   preprocessing - a line specifying how to preprocess: options are
%       '' (empty string) - no preprocessing
%   	1:d = apply  SVD and select the first normalized d dimensions
%   [1:3], [1,3:4], [1,3,5] etc  = any other combination of the SVD normalized dimensions
%   sigma -  for the qc algorithm (default = 0.5)
% Output
% inputStruct
function [inputStruct] = initTDQCparams(dataInputStr,preprocessing,sigma)
inputStruct= initStruct();
inputStruct.dataInputStr =dataInputStr;
if length(preprocessing)
    inputStruct.preprocessing=2;
    inputStruct.dims =str2num(preprocessing);
end
 inputStruct.sigma=str2num(sigma);
 inputStruct.numelems=size(evalin('base',dataInputStr),1);

function [inputStruct]= initStruct()
inputStruct.dataInputStr =[];
inputStruct.realMappingStr =[];
inputStruct.preprocessing=0;
inputStruct.dims = [];
inputStruct.clustercolumns =0;
inputStruct.algorithm =4;
inputStruct.numclust =0;
inputStruct.jaccard=0;

inputStruct.numelems=0;
inputStruct.iscorr=0;
%QC specific
inputStruct.sigma = 0.5;
inputStruct.steps =50;%can be constant
inputStruct.ratio =100;%can be constant;
inputStruct.save=0;
function [inputStruct] = fillStruct(inputStruct,field,value)

switch lower(field)
    case 'data'
        if ischar(value)
            inputStruct.dataInputStr     = value;
        else
            error('Error: data must be a name of and existing matlab variable');
        end
    case 'realmapping'
        if ischar(value)
            inputStruct.realMappingStr     = value;
        else
            error('Error: realmapping must be a name of and existing matlab variable');
        end
    case 'preprocessing'
        num = str2num(value);
        if ( length(num) < 1 ) | (0 == isnumeric(num))  |  (num ~=0 &num ~=1 & num ~=2)
            error('Error: preprocessing must be an integer number with values: 0 (no preprocessing), 1 (only SVD) and 2 (SVD + normalization)');
        else
            inputStruct.preprocessing = num;
        end
    case 'dims'
        num = str2num(value);%[1:3], '[1,3:4], [1,3,5]
        if length(num)<1 | 0 == isnumeric(num)
            error('Error: dims must be an integer array with numbers greater than 0');
        else
            inputStruct.dims =num;
        end
    case 'clustercolumns'
        num =str2num(value);
        if length(num)~=1 | 0==isnumeric(num) | (num~=0&num~=1)
            error('Error: clustercolumns must be an integer with values 0 (cluster rows) or 1 (cluster columns)');
        else
            inputStruct.clustercolumns = num;
        end
    case  'algorithm'
        num =str2num(value);
        if length(num)~=1 | 0==isnumeric(num) | num<1 | num > 4
            error('Error: algorithm must be an integer with values greater than  1');
        else
            inputStruct.algorithm = num;
        end
    case 'sigma'
        num =str2num(value);
        if length(num)~=1 | 0==isnumeric(num) | num<0
            error('Error: sigma must be a number greater than  0');
        else
            inputStruct.sigma = num;
        end
    case 'numclust'
        num =str2num(value);
        if length(num)~=1 | 0==isnumeric(num) | num<1
            error('Error: numclust must be a number greater than  1');
        else
            inputStruct.numclust = num;
        end
    case 'steps'
        num =str2num(value);
        if length(num)~=1 | 0==isnumeric(num) | num<0
            error('Error: steps must be an integer greater than  0');
        else
            inputStruct.steps = num;
        end

    case 'ratio'
        num =str2num(value);
        if length(num)~=1 | 0==isnumeric(num) | num<0| num >100
            error('Error: ratio must be a number greater than  0 and not greater than 100');
        else
            inputStruct.ratio = num;
        end
    case 'numelems'
        num=str2num(value);
        inputStruct.numelems=num;
    case 'iscorr'
        num=str2num(value);
        inputStruct.iscorr=num;
    case 'save'
        num=str2num(value);
        inputStruct.save=num;
end


