% function []=paintEnrichedVertices(p,enrichmentMatrix);
% Input -
% p parents array
% enrichmentMatrix - level of enrichments - only enriched vertices are colored
% indices - for mapping with the p array
% paint the 'good' partitions
%   useFDR -    1 - yes (default)
%               0 - no
% significance threshold

function [score]=paintEnrichedVertices(p,enrichmentMatrix,indices,paintFactor,useFDR,threshold)
% fdr correct
if useFDR
    iters =size(enrichmentMatrix,2);
    correctedMatrix=zeros(size(enrichmentMatrix));
    for ind = 1:iters
        [newPVals]= fdrCorrection(enrichmentMatrix(:,ind));
        correctedMatrix(:,ind) = newPVals;
    end
else
    correctedMatrix=enrichmentMatrix;
end
[vals,inds,score] = findSignificantVertices(correctedMatrix,paintFactor,threshold);
%markers = [ .5  0.3  0; 1 0 0 ;0 0 1;  0 1 0; 1 1 0; 1 0 1 ; 0 1 1; 0.5 0.5 0.5];
[x1,y1,h]=treelayout(p);
nElem = (length(p) + 1)/2;
global hash;
pValsNoFDR = min(enrichmentMatrix')';
pValsFDR = min(correctedMatrix')';
leaves = ones(nElem*2 -1,1);
for ind = 1: length(pValsFDR)
    branch = ind + nElem;
    corrInd = find (indices==branch);
    hash(corrInd,5) = pValsNoFDR(ind);
    hash(corrInd,6) = pValsFDR(ind);
end

[relevantVals]=find(vals>0);
for ind = 1:length(relevantVals)
    currVertex = relevantVals(ind)+nElem;
    currInd = find (indices==currVertex);
    val = vals(relevantVals(ind));
    col = inds(relevantVals(ind));
    marker=  getColorOfCluster(col);
    plot(x1(currInd), y1(currInd), '.','Color',marker,'MarkerSize',val);
    pVal = min(correctedMatrix(relevantVals(ind),:));
end
nonSignificantBranches = setdiff([1:1:nElem],relevantVals);
for ind = 1:length(nonSignificantBranches)
    currVertex = nonSignificantBranches(ind)+nElem;
    currInd = find (indices==currVertex);
    plot(x1(currInd), y1(currInd), 'o','MarkerEdgeColor','k', 'MarkerFaceColor','w', 'MarkerSize',paintFactor);
end
