%   function [familyTree, partitionMatrix]=tdqc(filename,show)
%   Recursive/ Devide & Conquer  Quantum Clustering
%   Input
%   dataInputStr - the input dataset (the string representing the variable)
%   preprocessing - a line specifying how to preprocess: options are
%       '' (empty string) - no preprocessing
%   	1:d = apply  SVD and select the first normalized d dimensions
%   	1:d1, d2, d3:d4 etc  = any other combination of the SVD normalized dimensions
%   sigma -  for the qc algorithm (default = 0.5)
%   Output
%   familyTree- A Cell based data structure representation of the hierarchy
%   partitionMatrix - a partition matrix representation of the hierarchy
%   (equivalent to the previous)
%   For more information on the we refer to tree2partition function
%   (type "help  tree2partition")
%   childs - parents/childs tree - a representation of the parents/childs relations in
%   of the tree (good for the plotTree function)
function [familyTree,partitionMatrix,childs]=tdqc(dataInputStr,preprocessing, sigma)
tic
inputStruct = initTDQCparams(dataInputStr,preprocessing, sigma);% initiate the parameters for the algorithm
fatherDims = num2str(1:inputStruct.numelems);
[familyTree] =tdqcInternal (inputStruct,fatherDims,[]);%actual call to algorithm
toc
[partitionMatrix]= tree2partition(familyTree);%the equivalent (more practical representation of the tree)
childs = tree2childs(familyTree);    
toc

%recursive internal call
function [familyTree] =tdqcInternal (inputStruct,fatherDims,familyTree)
length(str2num(fatherDims));
[cnt,y] = size(familyTree);
cnt = cnt +1;
calcMapping=1;%dummy start
originalSigma= inputStruct.sigma;%for later

[calcMapping,jm,efficiency, purity,globalMin]    =silentCompareMethodsTool([],0,inputStruct,fatherDims);
while max(max(calcMapping)) ==1
    inputStruct.sigma=inputStruct.sigma*.8;%make the sigma smaller...
    [calcMapping,jm,efficiency, purity,globalMin]    =silentCompareMethodsTool([],0,inputStruct,fatherDims);
end
%now we are back in business...
inputStruct.sigma=originalSigma;
minSetIds = find(calcMapping == globalMin);
minSetName = num2str(minSetIds');


otherSetsIds = find((calcMapping ~= globalMin) & (calcMapping ~= 0) );
otherSetsName = num2str(otherSetsIds');
familyTree(cnt,1) = {fatherDims};
familyTree(cnt,2) = {minSetName};
familyTree(cnt,3) = {otherSetsName};
%familyTree(cnt,4) = {bic};
% call two recursive calls
if length(minSetIds)>2
    [familyTree] =tdqcInternal (inputStruct,minSetName,familyTree);
elseif length(minSetIds)==2
    familyTree(cnt+1,1) = {minSetName};
    familyTree(cnt+1,2) = {num2str(minSetIds(1))};
    familyTree(cnt+1,3) = {num2str(minSetIds(2))};
end
if length(otherSetsIds)>2
    [familyTree] =tdqcInternal (inputStruct,otherSetsName,familyTree);
elseif length(otherSetsIds)==2
    [cnt,y] = size(familyTree);
    cnt = cnt +1;
    familyTree(cnt,1) = {otherSetsName};
    familyTree(cnt,2) = {num2str(otherSetsIds(1))};
    familyTree(cnt,3) = {num2str(otherSetsIds(2))};
end






